lua_error

Function lua_error 

pub unsafe extern "C-unwind" fn lua_error(l: *mut lua_State) -> c_int
Generates a Lua error. The error message (which can actually be a Lua value of any type) must be on the stack top. This function does a long jump, and therefore never returns. (see luaL_error). [-1, +0, v]