lua_getfield

Function lua_getfield 

pub unsafe extern "C-unwind" fn lua_getfield(
    l: *mut lua_State,
    index: c_int,
    k: *const c_char,
)
Pushes onto the stack the value t[k], where t is the value at the given valid index. As in Lua, this function may trigger a metamethod for the “index” event [-0, +1, e]