pub type lua_Reader = extern "C" fn(l: *mut lua_State, data: *mut c_void, size: *mut size_t) -> *const c_char;Expand description
The reader function used by lua_load. Every time it needs another piece
of the chunk, lua_load calls the reader, passing along its data
parameter. The reader must return a pointer to a block of memory with a new
piece of the chunk and set size to the block size. The block must exist
until the reader function is called again. To signal the end of the chunk,
the reader must return NULL or set size to zero. The reader function may
return pieces of any size greater than zero.