pub struct Nil;Trait Implementations
sourceimpl<L> LuaRead<L> for Nil where
L: AsLua,
impl<L> LuaRead<L> for Nil where
L: AsLua,
sourcefn lua_read_at_position(lua: L, index: NonZeroI32) -> Result<Self, L>
fn lua_read_at_position(lua: L, index: NonZeroI32) -> Result<Self, L>
Reads the data from Lua at a given position.
fn lua_read_at_maybe_zero_position(lua: L, index: i32) -> Result<Self, L>
fn n_values_expected() -> i32
sourceimpl Ord for Nil
impl Ord for Nil
sourceimpl PartialOrd<Nil> for Nil
impl PartialOrd<Nil> for Nil
sourcefn partial_cmp(&self, other: &Nil) -> Option<Ordering>
fn partial_cmp(&self, other: &Nil) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl<L> Push<L> for Nil where
L: AsLua,
impl<L> Push<L> for Nil where
L: AsLua,
sourceimpl<L> PushInto<L> for Nil where
L: AsLua,
impl<L> PushInto<L> for Nil where
L: AsLua,
impl Copy for Nil
impl Eq for Nil
impl<L> PushOne<L> for Nil where
L: AsLua,
impl<L> PushOneInto<L> for Nil where
L: AsLua,
impl StructuralEq for Nil
impl StructuralPartialEq for Nil