pub struct PushGuard<L> where
    L: AsLua
{ /* private fields */ }
RAII guard for a value pushed on the stack.

You shouldn’t have to manipulate this type directly unless you are fiddling with the library’s internals.

Implementations

Creates a new PushGuard from this Lua context representing size items on the stack. When this PushGuard is destroyed, size items will be popped.

Safety

There must be at least size elements on the lua stack and it must be safe to drop them at the same time with this PushGuard.

Returns the number of elements managed by this PushGuard.

Prevents the value from being popped when the PushGuard is destroyed, and returns the number of elements on the Lua stack.

Safety

The values on the stack will not be popped automatically, so the caller must ensure nothing is leaked.

Destroys the guard, popping the value. Returns the inner part, which returns access when using by-value capture.