pub struct ToString(pub String);Expand description
String wrapper struct that can be used to read a lua value by converting it
to string possibly using __tostring metamethod.
Tuple Fields
0: StringTrait Implementations
sourceimpl<L> LuaRead<L> for ToString where
L: AsLua,
impl<L> LuaRead<L> for ToString where
L: AsLua,
sourcefn lua_read_at_position(lua: L, index: NonZeroI32) -> Result<Self, L>
fn lua_read_at_position(lua: L, index: NonZeroI32) -> Result<Self, L>
Reads the data from Lua at a given position.
fn n_values_expected() -> i32
fn lua_read_at_maybe_zero_position(lua: L, index: i32) -> Result<Self, L>