pub struct True;Trait Implementations
sourceimpl<'de> Deserialize<'de> for True
impl<'de> Deserialize<'de> for True
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
sourceimpl<L> LuaRead<L> for True where
L: AsLua,
impl<L> LuaRead<L> for True where
L: AsLua,
sourcefn lua_read_at_position(lua: L, index: NonZeroI32) -> Result<Self, L>
fn lua_read_at_position(lua: L, index: NonZeroI32) -> Result<Self, L>
Reads the data from Lua at a given position.
fn n_values_expected() -> i32
fn lua_read_at_maybe_zero_position(lua: L, index: i32) -> Result<Self, L>
sourceimpl Ord for True
impl Ord for True
1.21.0 · sourcefn max(self, other: Self) -> Self
fn max(self, other: Self) -> Self
Compares and returns the maximum of two values. Read more
1.21.0 · sourcefn min(self, other: Self) -> Self
fn min(self, other: Self) -> Self
Compares and returns the minimum of two values. Read more
1.50.0 · sourcefn clamp(self, min: Self, max: Self) -> Self where
Self: PartialOrd<Self>,
fn clamp(self, min: Self, max: Self) -> Self where
Self: PartialOrd<Self>,
Restrict a value to a certain interval. Read more
sourceimpl PartialOrd<True> for True
impl PartialOrd<True> for True
sourcefn partial_cmp(&self, other: &True) -> Option<Ordering>
fn partial_cmp(&self, other: &True) -> Option<Ordering>
This method returns an ordering between self and other values if one exists. Read more
1.0.0 · sourcefn lt(&self, other: &Rhs) -> bool
fn lt(&self, other: &Rhs) -> bool
This method tests less than (for self and other) and is used by the < operator. Read more
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
sourceimpl<L> Push<L> for True where
L: AsLua,
impl<L> Push<L> for True where
L: AsLua,
sourceimpl<L> PushInto<L> for True where
L: AsLua,
impl<L> PushInto<L> for True where
L: AsLua,
impl Copy for True
impl Eq for True
impl<L> PushOne<L> for True where
L: AsLua,
impl<L> PushOneInto<L> for True where
L: AsLua,
impl StructuralEq for True
impl StructuralPartialEq for True