Extension trait for Push. Guarantees that only one element will be pushed.
This should be implemented on most types that implement Push, except for tuples.
Note: Implementing this trait on a type that pushes multiple elements will most likely
result in panics.
sourceimpl<L, Z, R, A: 'static, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (A, B, C, D, E, F, G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(A, B, C, D, E, F, G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(A, B, C, D, E, F, G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, B: 'static, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (B, C, D, E, F, G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(B, C, D, E, F, G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(B, C, D, E, F, G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, C: 'static, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (C, D, E, F, G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(C, D, E, F, G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(C, D, E, F, G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, D: 'static, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (D, E, F, G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(D, E, F, G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(D, E, F, G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, E: 'static, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (E, F, G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(E, F, G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(E, F, G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, F: 'static, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (F, G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(F, G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(F, G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, G: 'static, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (G, H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(G, H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(G, H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, H: 'static, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (H, I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(H, I, J, K, M, N) -> R,
Self: Copy + 'static,
(H, I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, I: 'static, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (I, J, K, M, N), R> where
L: AsLua,
Z: FnMut(I, J, K, M, N) -> R,
Self: Copy + 'static,
(I, J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, J: 'static, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (J, K, M, N), R> where
L: AsLua,
Z: FnMut(J, K, M, N) -> R,
Self: Copy + 'static,
(J, K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,
sourceimpl<L, Z, R, K: 'static, M: 'static, N: 'static> PushOne<L> for Function<Z, (K, M, N), R> where
L: AsLua,
Z: FnMut(K, M, N) -> R,
Self: Copy + 'static,
(K, M, N): for<'p> LuaRead<&'p InsideCallback>,
R: PushInto<InsideCallback> + 'static,