Enum tlua::AnyLuaValue
source · [−]pub enum AnyLuaValue {
LuaString(String),
LuaAnyString(AnyLuaString),
LuaNumber(f64),
LuaBoolean(bool),
LuaArray(Vec<(AnyLuaValue, AnyLuaValue)>),
LuaNil,
LuaOther,
}Expand description
Represents any value that can be stored by Lua
Variants
LuaString(String)
LuaAnyString(AnyLuaString)
LuaNumber(f64)
LuaBoolean(bool)
LuaArray(Vec<(AnyLuaValue, AnyLuaValue)>)
LuaNil
LuaOther
The “Other” element is (hopefully) temporary and will be replaced by “Function” and “Userdata”. A panic! will trigger if you try to push a Other.