pub unsafe extern "C-unwind" fn lua_createtable(
l: *mut lua_State,
narr: c_int,
nrec: c_int,
)Expand description
Creates a new empty table and pushes it onto the stack. The new table
has space pre-allocated for narr array elements and nrec non-array
elements. This pre-allocation is useful when you know exactly how many
elements the table will have. Otherwise you can use the function
lua_newtable.
[-0, +1, m]