pub unsafe extern "C-unwind" fn lua_gettable(
l: *mut lua_State,
index: c_int,
)Expand description
Pushes onto the stack the value t[k], where t is the value at the
given valid index and k is the value at the top of the stack.
[-1, +1, e]
This function pops the key from the stack (putting the resulting value in its place). As in Lua, this function may trigger a metamethod for the “index” event