pub struct PushGuard<L> where
L: AsLua, { /* private fields */ }Expand description
RAII guard for a value pushed on the stack.
You shouldn’t have to manipulate this type directly unless you are fiddling with the library’s internals.
Implementations
sourceimpl<L: AsLua> PushGuard<L>
impl<L: AsLua> PushGuard<L>
sourcepub unsafe fn new(lua: L, size: i32) -> Self
pub unsafe fn new(lua: L, size: i32) -> Self
Creates a new PushGuard from this Lua context representing size items on the stack.
When this PushGuard is destroyed, size items will be popped.
Safety
There must be at least size elements on the lua stack and it must be
safe to drop them at the same time with this PushGuard.
pub fn assert_one_and_forget(self) -> i32
sourcepub unsafe fn forget(self) -> i32
pub unsafe fn forget(self) -> i32
Prevents the value from being popped when the PushGuard is destroyed, and returns the
number of elements on the Lua stack.
Safety
The values on the stack will not be popped automatically, so the caller must ensure nothing is leaked.
sourcepub fn into_inner(self) -> L
pub fn into_inner(self) -> L
Destroys the guard, popping the value. Returns the inner part, which returns access when using by-value capture.