pub trait PushOneInto<L: AsLua>: PushInto<L> { }
Extension trait for PushInto. Guarantees that only one element will be pushed.

This should be implemented on most types that implement PushInto, except for tuples.

Note: Implementing this trait on a type that pushes multiple elements will most likely result in panics.

Implementations on Foreign Types

Implementors